@@ -1,6 +1,6 @@
 # pywws - Python software for USB Wireless Weather Stations
 # http://github.com/jim-easterbrook/pywws
-# Copyright (C) 2018  pywws contributors
+# Copyright (C) 2018-21  pywws contributors
 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -60,7 +60,7 @@ import pywws
 from pywws.conversions import rain_inch
 from pywws.process import get_day_end_hour
 import pywws.service
-from pywws.timezone import timezone
+from pywws.timezone import time_zone
 
 __docformat__ = "restructuredtext en"
 service_name = os.path.splitext(os.path.basename(__file__))[0]
@@ -116,8 +116,8 @@ class ToService(pywws.service.CatchupDataService):
     def rain_day_local(self, data):
         # compute rain since day start
         day_end_hour, use_dst = get_day_end_hour(self.context.params)
-        day_start = timezone.local_replace(
-            data['idx'], use_dst=use_dst, hour=day_end_hour, minute=0, second=0)
+        day_start = time_zone.day_start(
+            data['idx'], day_end_hour, use_dst=use_dst)
         day_start = self.context.calib_data.nearest(day_start)
         return max(
             data['rain'] - self.context.calib_data[day_start]['rain'], 0.0)
